# Rare

## A frontend for legendary, the open source Epic Games Launcher alternative

Rare is currently considered beta software and in no way feature-complete. You **will** run into issues, so make backups
first!

### Requirements

- requests,
- pillow
- pyqt5
- legendary-gl
- PyQtWebengine

## Installation

### Installation via pip

Execute *pip install Rare* for all users Or *pip install Rare --user* for only one user

### Windows Simple

Download Rare.exe and place it somewhere in PATH

### Linux

- For Arch Linux is an AUR package available: [rare-git](https://aur.archlinux.org/packages/rare-git)
- Other distributions have to install it with pip or clone the repo and install it manually: *python3 setup.py install*

### Implemented

- Launch, install and uninstall games
- Authentication(Import from existing installation and via Browser)
- In-app Browser to buy games
- Settings

### Todos
- Download Progressbar
- Sync saves
- Translations
- Design(Pretty Stylesheets, Icon view)

### Images

![alt text](https://github.com/Dummerle/Rare/blob/master/Screenshots/GameList.png?raw=true)
![alt text](https://github.com/Dummerle/Rare/blob/master/Screenshots/Uninstalled.png?raw=true)
![alt text](https://github.com/Dummerle/Rare/blob/master/Screenshots/Settings.png?raw=true)

If you have features you want to have in this app, create an issue on github or build it yourself. Please report bugs(
Especially Windows)

